physics - Is there a safe but weird distance from black hole merger? - Worldbuilding Stack Exchange
Description: I wish to create a world such that it can support the following plot point: the world experiences gravitational waves that are directly noticeable to the human population (i.e. they can feel or see...

# Is there a safe but weird distance from black hole merger?

Ask Question
Asked 5 years, 1 month ago
Modified 5 years, 1 month ago
Viewed 665 times
8
$\begingroup$

I wish to create a world such that it can support the following plot point: the world experiences gravitational waves that are directly noticeable to the human population (i.e. they can feel or see the effects themselves without instruments) without being so strong that everything gets spaghettified.

The most obvious way to arrange this seems to be to have a pair of black holes undergo a merger at a suitable distance: not so close that everything gets ripped apart, and not so far away that the gravitational waves have become un-noticeably weak.

My question has 2 parts but they are directly related so it wouldn't make sense to split this into 2 separate questions:

(a) assuming a pair of 30 solar mass black holes as detected the other year by LIGO, what distance from the event would provide gravitational waves of the weird but not deadly strength that I need; and

(b) at such a distance from the event, would you be safe from other consequences of the black hole merger, or would something else such as the intensity of high energy particle emissions kill you anyway?

I'm open to any kind of habitat for my world, it could be a planet or a deep space habitat or generation ship or whatever. If the gravitational waves would rule out particular kinds of world then I'd be keen to hear why (e.g. maybe waves strong enough to be noticeable to humans would shatter a planet but a space habitat might be small enough to survive). In my story I may make limited use of unobtainium for interstellar travel, but I want the physical effects of the black hole to be as hard science as possible.

If a black hole merger is out of the question as too dangerous, I'd be happy to receive reality-check level suggestions of alternative events that could safely create the kind of noticeable gravitational wave I want.

- physics
- hard-science
- black-holes

asked Nov 28, 2019 at 10:33
Adrian K-B. Adrian K-B.
3,12388 silver badges1616 bronze badges
$\endgroup$
4

- 3
  $\begingroup$ Gravitational waves are mind-bogglingly tiny. Fractions of the diameter of a proton is the displacement or size change due to the passage of a gravitational wave. To make your idea work you will need to rewrite general relativity for it to be remotely credible. Otherwise you have to be so close to the merging black holes you would be swallowed too. Asking for hard-science answers is wrong. You might get close with "science-based". $\endgroup$
  – a4android
  Commented Nov 28, 2019 at 11:06
- $\begingroup$ Gravitational waves big enough for a meatsack to feel are world-endingly powerful. $\endgroup$
  – Starfish Prime
  Commented Nov 28, 2019 at 11:21
- 1
  $\begingroup$ This is exactly why I tagged hard science rather than science-based. @a4android Obviously the gravitational waves we detect using ligo are imperceptible, but that is because the black holes are extremely far away. I'd like an answer to include calculations to show what distance you would have to be to feel them but not be killed. And starfish prime, I'd ideally like numbers to back up your assertion, but world-ending isn't necessarily a problem if I can put the characters in a small spaceship or habitat that could survive. $\endgroup$
  – Adrian K-B.
  Commented Nov 28, 2019 at 11:28
- 1
  $\begingroup$ My source told me you need to get close like in-your-face close to experience a distortion of your body by millimetres, then again the tidal force would have long already turn you into a beam of particles. $\endgroup$
  – user6760
  Commented Nov 28, 2019 at 12:54

Add a comment |

## 2 Answers 2

Sorted by: Reset to default
5
$\begingroup$

I think I can now answer my own question, having come across some decent references I hadn't found before asking it. I found the equation for the gravitational strain $h$ - the proportional change in length of an object due to gravitational waves from a mass $M$:

$$h \approx {{GM} \over c^2} \times {1 \over r} \times {v^2 \over c^2}$$

(Source of formula)

The first term is of the order of the size of the black hole, or about 45 km for a 30 solar mass ($M_{\odot}$) black hole. Near collision the black holes move close to the speed of light so the last term is $\approx 1$. Then the strain falls off as $1 \over r$, so even if you could sense a brief stretching of 1 part in 10,000 (about 0.2 mm along the length of your body) you would need to be 450,000 km (about 1.9 times the average distance between Earth and the Moon) from two 30 $M_{\odot}$ black holes orbiting each other at near light speed.

My takeaway is really just how weak gravitational waves are for the amount of energy that goes into them (for the LIGO 60 $M_{\odot}$ collision about 3 $M_{\odot}$ was converted from mass energy into gravitational waves). For an object orbiting 60 $M_{\odot}$ at that distance the orbital period would be 11.2 minutes. The gravitational tidal acceleration across a body of length d is given by: $$a={{2 G M d} \over {r^3}}$$ which works out as 5.8 micronewtons, so the astronauts would be safe from spaghettification at a range where they could experience noticeable but not intrinsically fatal gravitational waves. At that distance I guess it's still highly likely radiation from accreting matter would be fatal, so my scenario would rely on the black hole pair being located in an almost perfect void, which leads to other questions (how did they end up in such a perfect void, how did the characters end up at just such a perfect distance from them?)

(Edited to remove erroneous statement about centripetal acceleration.)

edited Nov 29, 2019 at 9:14
answered Nov 28, 2019 at 12:21
Adrian K-B. Adrian K-B.
3,12388 silver badges1616 bronze badges
$\endgroup$
4

- 1
  $\begingroup$ I was just about to cobble together an answer that said more or less the same thing. There's a nice writeup with some example values here. $\endgroup$
  – Starfish Prime
  Commented Nov 28, 2019 at 12:59
- 2
  $\begingroup$ in orbit you don't fell any acceleration, you're in free fall. $\endgroup$
  – ths
  Commented Nov 28, 2019 at 15:36
- $\begingroup$ @ths Agreed. You need to work out the tidal effects on the orbiting body to determine whether orbiting at a particular distance would be fatal. $\endgroup$
  – notovny
  Commented Nov 28, 2019 at 15:38
- 1
  $\begingroup$ This answer reminds me of what-if.xkcd.com/73 $\endgroup$
  – Borgh
  Commented Nov 29, 2019 at 10:04

Add a comment |
1
$\begingroup$

When gravitational waves reach Earth, they usually give a strain of $\delta L \over L$$=10^{-21}$.

If we assume that they scale with the distance the same way electromagnetic waves do, thus following the inverse square law, we can get an estimate of the distance needed.

LIGO detected the first merger of black holes at 1.3 billion light years away.

If we would get to 1 light year away from the merger, under the above hypothesis we would get a strain of $10^{-21} \times (1.3 \cdot 10^9)^2=10^{-3}$. This means that on 1 meter length we would notice a 1 mm oscillation, which is something we are able to sense.

On the other hand, supernova explosions are lethal well beyond 1 light year, and though extremely powerful they are probably tiny when compared with black hole merger.

Wrapping up, there is probably a distance at which our body can feel gravitational wave produced by merging black holes, but that feeling would probably we quickly swept away by a shower of high energy particles, unless the two black holes have both no accretion disk.

Addendum after Starfish Prime's comment:

If instead the scaling goes like $1/r$, then at a distance of 1 light year the strain would be $10^{-21} \times (1.3 \cdot 10^9)=10^{-9}$. Thus too low. To make it back to $10^{-3}$ the observer would need to be to $1/1000$ of a light year, or $9 \cdot 10^9$ km, twice the distance between Neptune and the Sun.

edited Jun 16, 2020 at 11:03
Community Bot
1
answered Nov 28, 2019 at 12:27
L.Dutch♦L.Dutch
301k6161 gold badges620620 silver badges1.3k1.3k bronze badges
$\endgroup$
2

- 2
  $\begingroup$ Turns out that gravity waves don't necessarily behave the way you might think they do. Specifically, the energy they carry does follow an inverse square relationship, but the amplitude (the important bit in this case) is a more simple 1/r thing. Anyway, it turns out that for a 1 part in a 1000 length change, you need to be more like a 10000km away, not a whole lightyear. $\endgroup$
  – Starfish Prime
  Commented Nov 28, 2019 at 13:03
- 1
  $\begingroup$ I'd recommend removing the whole first half of this, as it depends on the signal falling off as $1/r^2$, whereas the last paragraph correctly uses the $1/r$ dependence. $\endgroup$
  – HDE 226868 ♦
  Commented Jun 2, 2020 at 18:30

Add a comment |

## You must log in to answer this question.

##
Not the answer you're looking for? Browse other questions tagged

- physics
- hard-science
- black-holes

.